Response

Enum Response 

pub enum Response {
    Analyze(AnalysisResponse),
    NoResults {
        id: String,
        turn_number: usize,
    },
    QueryVersion {
        id: String,
        version: String,
        git_hash: String,
    },
    ClearCache {
        id: String,
    },
    Terminate {
        id: String,
        terminate_id: String,
        turn_numbers: Option<Vec<usize>>,
    },
    TerminateAll {
        id: String,
        turn_numbers: Option<Vec<usize>>,
    },
    QueryModels {
        id: String,
        models: Vec<Model>,
    },
    GeneralError {
        error: String,
    },
    FieldError {
        id: String,
        error: String,
        field: String,
    },
    FieldWarning {
        id: String,
        warning: String,
        field: String,
    },
}
A response from the analysis engine.

Variants



Analyze(AnalysisResponse)

The result of analyzing a position.



NoResults

Indicates that analysis was terminated before analyzing the specified position.

Fields

id: String

The request ID.

turn_number: usize

The position index, where 0 is the position before the first move.



QueryVersion

KataGo’s version information.

Fields

id: String

The request ID.

version: String

A string indicating the most recent KataGo release version that this version is a descendant of, such as "1.6.1".

git_hash: String

The precise git hash this KataGo version was compiled from, or the string "<omitted>" if KataGo was compiled separately from its repo or without Git support.



ClearCache

Indicates that the cache was cleared.

Fields

id: String

The request ID.



Terminate

Acknowledgement of a terminate request. The engine will proceed to send NoResults or partial Analyze responses for each position after they have been terminated.

Fields

id: String

The request ID.

terminate_id: String

The ID of the request being terminated.

turn_numbers: Option<Vec<usize>>

The positions being terminated, if specified in the request.



TerminateAll

Acknowledgement of a request to terminate all analyses. The engine will proceed to send NoResults or partial Analyze responses for each position after they have been terminated.

Fields

id: String

The request ID.

turn_numbers: Option<Vec<usize>>

The positions being terminated, if specified in the request.



QueryModels

Information about the currently loaded neural network models.

Fields

id: String

The request ID.

models: Vec<Model>

A list of available models.



GeneralError

An error with no known associated request.

Fields

error: String

The error message.



FieldError

An error in processing a request.

Fields

id: String

The request ID.

error: String

The error message.

field: String

The request field which is the source of the error.



FieldWarning

A warning in processing a request. The engine will still generate analysis responses for the request.

Fields

id: String

The request ID.

warning: String

The warning message.

field: String

The request field which is the source of the warning.