pub struct AnalysisResponse {
pub id: String,
pub is_during_search: bool,
pub turn_number: usize,
pub move_infos: Vec<MoveInfo>,
pub root_info: RootInfo,
pub ownership: Option<Vec<f64>>,
pub ownership_stdev: Option<Vec<f64>>,
pub policy: Option<Vec<f64>>,
pub human_policy: Option<Vec<f64>>,
}Expand description
The result of analyzing a position.
Fields
id: StringThe request ID.
is_during_search: boolWhether this is a partial analysis result. false indicates no more responses will be sent.
turn_number: usizeThe position index, where 0 is the position before the first move.
move_infos: Vec<MoveInfo>The list of moves the engine considered.
root_info: RootInfoInformation about the root position.
ownership: Option<Vec<f64>>The ownership prediction, in row-major order.
ownership_stdev: Option<Vec<f64>>The standard deviation of the ownership prediction, in row-major order.
policy: Option<Vec<f64>>The policy prediction, in row-major order with the pass move at the end.
human_policy: Option<Vec<f64>>The humanSL policy prediction, in row-major order with the pass move at the end.