Error

Enum Error 

pub enum Error {
    Io(Arc<Error>),
    Serialization(Arc<Error>),
    StdinUnavailable,
    StdoutUnavailable,
    UnserializableConfig(String),
    KataGoGeneralError {
        error: String,
    },
    KataGoFieldError {
        error: String,
        field: String,
    },
    UnhandledWarnings(Vec<Warning>),
}
Errors that can occur while interacting with the analysis engine.

Variants



Io(Arc<Error>)

An I/O error occurred while launching, writing to, or reading from the analysis engine.



Serialization(Arc<Error>)

An error occurred while serializing or deserializing a message.



StdinUnavailable

The engine’s stdin was unavailable after launch.



StdoutUnavailable

The engine’s stdout was unavailable after launch.



UnserializableConfig(String)

The specified config setting’s value could not be serialized.



KataGoGeneralError

The analysis engine returned an error response without specifying which request caused it.

When this error occurs, all pending requests will return this error, even if they might have otherwise succeeded.

Fields

error: String

The error message provided by KataGo.



KataGoFieldError

The analysis engine returned an error response.

When this error occurs, all positions still being analyzed as part of the associated request will return this error, even if they might have otherwise succeeded.

Fields

error: String

The error message provided by KataGo.

field: String

The request field that caused the error.



UnhandledWarnings(Vec<Warning>)

The analysis engine returned a warning response which was converted to an error.

See also: WarningHandling