GameAnalysisProgress

Struct GameAnalysisProgress 

pub struct GameAnalysisProgress<W: WarningHandling = WarningsAsErrors> { /* private fields */ }
A collection of in-progress analysis operations for multiple positions in a single game.

Implementations

Source

impl<W: WarningHandling> GameAnalysisProgress<W>

pub async fn finish(self) -> WarningResult<HashMap<usize, AnalysisResult>, W>

Waits for all positions to finish analyzing and returns the results.

Positions that were terminated before any search was performed will not be included in the results.

pub fn positions(&self) -> &HashMap<usize, AnalysisProgress<W>>

Returns a reference to the raw collection of in-progress analysis operations for each position.

pub fn positions_mut(&mut self) -> &mut HashMap<usize, AnalysisProgress<W>>

Returns a mutable reference to the raw collection of in-progress analysis operations for each position.

pub fn into_positions(self) -> HashMap<usize, AnalysisProgress<W>>

Extracts the collection of in-progress analysis operations for each position and consumes this object.