MoveInfo

Struct MoveInfo 

pub struct MoveInfo {
Show 23 fields pub mv: Move, pub visits: u32, pub edge_visits: u32, pub winrate: f64, pub score_lead: f64, pub score_stdev: f64, pub score_selfplay: f64, pub prior: f64, pub no_result_value: Option<f64>, pub human_prior: Option<f64>, pub utility: f64, pub lcb: f64, pub utility_lcb: f64, pub weight: f64, pub edge_weight: f64, pub order: usize, pub play_selection_value: f64, pub is_symmetry_of: Option<Coord>, pub pv: Vec<Move>, pub pv_visits: Option<Vec<u32>>, pub pv_edge_visits: Option<Vec<u32>>, pub ownership: Option<Matrix<f64>>, pub ownership_stdev: Option<Matrix<f64>>,
}
The result of analyzing a candidate move.

Fields

mv: Move

The move location in GTP format ("A1", "pass", etc.). This corresponds to the move field in KataGo’s response.

visits: u32

The number of visits invested in this move.

edge_visits: u32

The number of visits the root “wants” to invest in this move.

winrate: f64

The winrate, in the range [0, 1].

score_lead: f64

The predicted number of points that the current side is leading by.

score_stdev: f64

The predicted standard deviation of the score lead.

score_selfplay: f64

The predicted score at the end of the game after selfplay.

prior: f64

The policy prior of this move.

no_result_value: Option<f64>

The predicted probability that the game will have a void result.

human_prior: Option<f64>

The humanSL policy prior of this move.

utility: f64

The utility of this move.

lcb: f64

The LCB of this move’s winrate.

utility_lcb: f64

The LCB of this move’s utility.

weight: f64

The total weight of this move’s visits.

edge_weight: f64

The total weight of the visits the root “wants” to invest in this move.

order: usize

The relative ranking of this move, where 0 is best.

play_selection_value: f64

The value used to determine the move ranking.

is_symmetry_of: Option<Coord>

If present, indicates the move that was actually searched to get the evaluation of this move.

pv: Vec<Move>

The principal variation for this move.

pv_visits: Option<Vec<u32>>

The number of visits invested in each position in the principal variation.

pv_edge_visits: Option<Vec<u32>>

The number of visits invested in each move in the principal variation.

ownership: Option<Matrix<f64>>

The ownership prediction.

ownership_stdev: Option<Matrix<f64>>

The standard deviation of the ownership prediction.

Implementations

Source

impl MoveInfo

pub fn from_engine_move_info(info: MoveInfo, width: u8, height: u8) -> Self

Creates a move analysis from the lower-level equivalent used by the engine module.

You probably don’t need to use this unless you’re directly using the lower-level API in the engine module.