RootInfo

Struct RootInfo 

pub struct RootInfo {
Show 21 fields pub winrate: f64, pub score_lead: f64, pub score_selfplay: f64, pub utility: f64, pub visits: u32, pub this_hash: String, pub sym_hash: String, pub current_player: Player, pub raw_winrate: f64, pub raw_lead: f64, pub raw_score_selfplay: f64, pub raw_score_selfplay_stdev: f64, pub raw_no_result_prob: f64, pub raw_st_wr_error: f64, pub raw_st_score_error: f64, pub raw_var_time_left: f64, pub human_winrate: Option<f64>, pub human_score_mean: Option<f64>, pub human_score_stdev: Option<f64>, pub human_st_wr_error: Option<f64>, pub human_st_score_error: Option<f64>,
}
The result of analyzing the root position.

Fields

winrate: f64

The winrate, in the range [0, 1].

score_lead: f64

The predicted number of points that the current side is leading by.

score_selfplay: f64

The predicted score at the end of the game after selfplay.

utility: f64

The utility.

visits: u32

The number of visits received.

this_hash: String

The hash of this position.

sym_hash: String

The hash of this position that is invariant under board symmetries.

current_player: Player

The player to move.

raw_winrate: f64

The winrate prediction from the neural network.

raw_lead: f64

The score lead prediction from the neural network.

raw_score_selfplay: f64

The selfplay score prediction from the neural network.

raw_score_selfplay_stdev: f64

The selfplay score standard deviation prediction from the neural network.

raw_no_result_prob: f64

The void result probability prediction from the neural network.

raw_st_wr_error: f64

The short-term winrate uncertainty prediction from the neural network.

raw_st_score_error: f64

The short-term score uncertainty prediction from the neural network.

raw_var_time_left: f64

A measure of how much meaningful game is left until the winner is known, predicted by the neural network.

human_winrate: Option<f64>

The winrate prediction from the humanSL neural network.

human_score_mean: Option<f64>

The score prediction from the humanSL neural network.

human_score_stdev: Option<f64>

The score standard deviation prediction from the humanSL neural network.

human_st_wr_error: Option<f64>

The short-term winrate uncertainty prediction from the humanSL neural network.

human_st_score_error: Option<f64>

The short-term score uncertainty prediction from the humanSL neural network.

Implementations

Source

impl RootInfo

pub fn from_engine_root_info(info: RootInfo) -> Self

Creates a root analysis from the lower-level equivalent used by the engine module.

You probably don’t need to use this unless you’re directly using the lower-level API in the engine module.