pub struct VersionInfo {
pub version: String,
pub git_hash: String,
}Expand description
KataGo’s version information.
Fields
version: StringA string indicating the most recent KataGo release version that this version is a descendant of,
such as "1.6.1".
git_hash: StringThe precise git hash this KataGo version was compiled from, or the string "<omitted>" if KataGo was
compiled separately from its repo or without Git support.