pub enum Response {
Analyze(AnalysisResponse),
NoResults {
id: String,
turn_number: usize,
},
QueryVersion {
id: String,
version: String,
git_hash: String,
},
ClearCache {
id: String,
},
Terminate {
id: String,
terminate_id: String,
turn_numbers: Option<Vec<usize>>,
},
TerminateAll {
id: String,
turn_numbers: Option<Vec<usize>>,
},
QueryModels {
id: String,
models: Vec<Model>,
},
GeneralError {
error: String,
},
FieldError {
id: String,
error: String,
field: String,
},
FieldWarning {
id: String,
warning: String,
field: String,
},
}Expand description
A response from the analysis engine.
Variants
Analyze(AnalysisResponse)
The result of analyzing a position.
NoResults
Indicates that analysis was terminated before analyzing the specified position.
Fields
QueryVersion
KataGo’s version information.
Fields
ClearCache
Indicates that the cache was cleared.
Terminate
Acknowledgement of a terminate request. The engine will proceed to send NoResults or
partial Analyze responses for each position after they have been terminated.
Fields
TerminateAll
Acknowledgement of a request to terminate all analyses. The engine will proceed to send
NoResults or partial Analyze responses for each position
after they have been terminated.
Fields
QueryModels
Information about the currently loaded neural network models.
GeneralError
An error with no known associated request.
FieldError
An error in processing a request.
Fields
FieldWarning
A warning in processing a request. The engine will still generate analysis responses for the request.