pub struct LaunchOptions {
pub katago_path: String,
pub config_path: String,
pub model_path: String,
pub inherit_stderr: bool,
pub human_model_path: Option<String>,
pub override_config: Option<Config>,
pub quit_without_waiting: bool,
}Expand description
Command line options for launching KataGo.
Fields
katago_path: StringThe path to the KataGo executable.
config_path: StringThe path to the config file.
model_path: StringThe path to the model file.
inherit_stderr: boolIf true, KataGo’s stderr output will be produced on the current process’s stderr.
Otherwise, it will be made available as Engine::stderr.
human_model_path: Option<String>The path to the humanSL model file.
override_config: Option<Config>Overrides to pass via -override-config.
quit_without_waiting: boolIf true, the engine will stop immediately when stdin is closed, instead of responding to pending requests.
Implementations
Sourceimpl LaunchOptions
impl LaunchOptions
Sourcepub fn new(katago_path: String, config_path: String, model_path: String) -> Self
pub fn new(katago_path: String, config_path: String, model_path: String) -> Self
Creates a new LaunchOptions.
Sourcepub fn with_inherit_stderr(self) -> Self
pub fn with_inherit_stderr(self) -> Self
Causes KataGo’s stderr output to be produced on the current process’s stderr.
Sourcepub fn with_human_model(self, human_model_path: String) -> Self
pub fn with_human_model(self, human_model_path: String) -> Self
Loads the humanSL model from the given path.
Sourcepub fn with_override_config(self, config: Config) -> Self
pub fn with_override_config(self, config: Config) -> Self
Passes the given options via -override-config.
Sourcepub fn with_quit_without_waiting(self) -> Self
pub fn with_quit_without_waiting(self) -> Self
Stop immediately when stdin is closed, instead of responding to pending requests.