pub struct GameAnalysisProgress<W: WarningHandling = WarningsAsErrors> { /* private fields */ }Expand description
A collection of in-progress analysis operations for multiple positions in a single game.
Implementations
Sourceimpl<W: WarningHandling> GameAnalysisProgress<W>
impl<W: WarningHandling> GameAnalysisProgress<W>
Sourcepub async fn finish(self) -> WarningResult<HashMap<usize, AnalysisResult>, W>
pub async fn finish(self) -> WarningResult<HashMap<usize, AnalysisResult>, W>
Waits for all positions to finish analyzing and returns the results.
Positions that were terminated before any search was performed will not be included in the results.
Sourcepub fn positions(&self) -> &HashMap<usize, AnalysisProgress<W>>
pub fn positions(&self) -> &HashMap<usize, AnalysisProgress<W>>
Returns a reference to the raw collection of in-progress analysis operations for each position.
Sourcepub fn positions_mut(&mut self) -> &mut HashMap<usize, AnalysisProgress<W>>
pub fn positions_mut(&mut self) -> &mut HashMap<usize, AnalysisProgress<W>>
Returns a mutable reference to the raw collection of in-progress analysis operations for each position.
Sourcepub fn into_positions(self) -> HashMap<usize, AnalysisProgress<W>>
pub fn into_positions(self) -> HashMap<usize, AnalysisProgress<W>>
Extracts the collection of in-progress analysis operations for each position and consumes this object.